/*
** pork_acct.h - account management.
** Copyright (C) 2002-2003 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#ifndef __PORK_ACCT_H
#define __PORK_ACCT_H

struct event;

struct aim_rights {
	u_int32_t max_buddies;
	u_int32_t max_groups;
	u_int32_t max_watchers;
	u_int32_t max_permit;
	u_int32_t max_deny;
	u_int32_t max_away_len;
	u_int32_t max_profile_len;
};

struct aim_priv {
	u_int32_t ref_count;

	char *username;
	char *passwd;
	char *profile;
	char *away_msg;

	char *proxy;
	char *proxy_user;
	char *proxy_passwd;
	char *server;

	u_int32_t warn_level;
	u_int32_t idle_time;
	u_int32_t flags;
	u_int32_t can_connect:1;
	u_int32_t connected:1;
	u_int32_t marked_idle:1;
	u_int32_t whois_hack:1;

	time_t last_update;
	time_t last_input;
	struct timeval last_flush;

	struct event *events;

	aim_session_t aim_session;
	struct aim_rights rights;
	aim_conn_t *bos_conn;
	aim_conn_t *chatnav_conn;
	dlist_t *chat_create_list;
	dlist_t *chat_list;

	hash_t autoreply;
	struct buddy_pref *buddy_pref;
	struct blist *blist;
};

struct pork_acct {
	char *username;
	struct aim_priv *priv;
};

struct pork_acct *pork_acct_add(char *user);
void pork_acct_del(dlist_t *node);
void pork_acct_del_all(void);
inline dlist_t *pork_acct_find(char *user);
inline struct aim_priv *pork_acct_get_priv(char *user);
inline void pork_acct_update(void);
void acct_update_blist_format(void *data, void *nothing __notused);
void acct_update_blist_color(void *data, void *nothing __notused);
struct aim_priv *pork_priv_init(const char *user);

#endif
